@@ -1,15 +1,18 @@
 from datetime import datetime
 import os
+from unittest import mock
+from unittest.mock import patch
 
-from aiohttp import ClientResponse, ClientSession
+from aiohttp import ClientOSError, ClientResponse, ClientSession
 from aiohttp.helpers import TimerNoop
 from aioresponses import CallbackResult, aioresponses
 import aiounittest
-from asynctest import mock
 import dateutil.parser
 from dateutil.tz import tzlocal, tzutc
+import pytest
 from yarl import URL
 
+from yalexs import api_async
 import yalexs.activity
 from yalexs.api_async import ApiAsync, _raise_response_exceptions
 from yalexs.api_common import (
@@ -29,8 +32,10 @@ from yalexs.api_common import (
     API_UNLOCK_URL,
     API_VALIDATE_VERIFICATION_CODE_URLS,
     HYPER_BRIDGE_PARAM,
+    ApiCommon,
 )
 from yalexs.bridge import BridgeDetail, BridgeStatus, BridgeStatusDetail
+from yalexs.const import DEFAULT_BRAND, Brand
 from yalexs.exceptions import AugustApiAIOHTTPError
 from yalexs.lock import LockDoorStatus, LockStatus
 
@@ -51,7 +56,10 @@ def utc_of(year, month, day, hour, minute, second, microsecond):
 class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbells(self, mock):
-        mock.get(API_GET_DOORBELLS_URL, body=load_fixture("get_doorbells.json"))
+        mock.get(
+            ApiCommon(DEFAULT_BRAND).get_brand_url(API_GET_DOORBELLS_URL),
+            body=load_fixture("get_doorbells.json"),
+        )
 
         api = ApiAsync(ClientSession())
         doorbells = sorted(
@@ -82,7 +90,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_doorbell_detail(self, mock):
         expected_doorbell_image_url = "https://image.com/vmk16naaaa7ibuey7sar.jpg"
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="K98GiDT45GUL"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="K98GiDT45GUL"),
             body=load_fixture("get_doorbell.json"),
         )
         mock.get(expected_doorbell_image_url, body="doorbell_image_mocked")
@@ -114,7 +124,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbell_detail_missing_image(self, mock):
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="K98GiDT45GUL"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="K98GiDT45GUL"),
             body=load_fixture("get_doorbell_missing_image.json"),
         )
 
@@ -137,7 +149,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbell_offline(self, mock):
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="231ee2168dd0"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="231ee2168dd0"),
             body=load_fixture("get_doorbell.offline.json"),
         )
 
@@ -164,7 +178,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbell_gen2_full_battery_detail(self, mock):
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="did"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="did"),
             body=load_fixture("get_doorbell.battery_full.json"),
         )
 
@@ -176,7 +192,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbell_gen2_medium_battery_detail(self, mock):
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="did"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="did"),
             body=load_fixture("get_doorbell.battery_medium.json"),
         )
 
@@ -188,7 +206,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_doorbell_gen2_low_battery_detail(self, mock):
         mock.get(
-            API_GET_DOORBELL_URL.format(doorbell_id="did"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_DOORBELL_URL)
+            .format(doorbell_id="did"),
             body=load_fixture("get_doorbell.battery_low.json"),
         )
 
@@ -199,7 +219,10 @@ class TestApiAsync(aiounittest.AsyncTestCase):
 
     @aioresponses()
     async def test_async_get_locks(self, mock):
-        mock.get(API_GET_LOCKS_URL, body=load_fixture("get_locks.json"))
+        mock.get(
+            ApiCommon(DEFAULT_BRAND).get_brand_url(API_GET_LOCKS_URL),
+            body=load_fixture("get_locks.json"),
+        )
 
         api = ApiAsync(ClientSession())
         locks = sorted(
@@ -220,9 +243,38 @@ class TestApiAsync(aiounittest.AsyncTestCase):
         self.assertEqual("000000000011", second.house_id)
         self.assertEqual(False, second.is_operable)
 
+    @aioresponses()
+    async def test_async_get_locks_yale_home_brand(self, mock):
+        mock.get(
+            ApiCommon(Brand.YALE_HOME).get_brand_url(API_GET_LOCKS_URL),
+            body=load_fixture("get_locks.json"),
+        )
+
+        api = ApiAsync(ClientSession(), brand=Brand.YALE_HOME)
+        locks = sorted(
+            await api.async_get_locks(ACCESS_TOKEN), key=lambda d: d.device_id
+        )
+
+        self.assertEqual(2, len(locks))
+
+        first = locks[0]
+        self.assertEqual("A6697750D607098BAE8D6BAA11EF8063", first.device_id)
+        self.assertEqual("Front Door Lock", first.device_name)
+        self.assertEqual("000000000000", first.house_id)
+        self.assertEqual(True, first.is_operable)
+
+        second = locks[1]
+        self.assertEqual("A6697750D607098BAE8D6BAA11EF9999", second.device_id)
+        self.assertEqual("Back Door Lock", second.device_name)
+        self.assertEqual("000000000011", second.house_id)
+        self.assertEqual(False, second.is_operable)
+
     @aioresponses()
     async def test_async_get_operable_locks(self, mock):
-        mock.get(API_GET_LOCKS_URL, body=load_fixture("get_locks.json"))
+        mock.get(
+            ApiCommon(DEFAULT_BRAND).get_brand_url(API_GET_LOCKS_URL),
+            body=load_fixture("get_locks.json"),
+        )
 
         api = ApiAsync(ClientSession())
         locks = await api.async_get_operable_locks(ACCESS_TOKEN)
@@ -238,7 +290,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_lock_detail_with_doorsense_bridge_online(self, mock):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="ABC"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="ABC"),
             body=load_fixture("get_lock.online_with_doorsense.json"),
         )
 
@@ -274,7 +328,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
         self, mock
     ):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="ABC"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="ABC"),
             body=load_fixture("get_lock.online_with_doorsense_disabled.json"),
         )
 
@@ -309,7 +365,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_lock_detail_bridge_online(self, mock):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="A6697750D607098BAE8D6BAA11EF8063"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="A6697750D607098BAE8D6BAA11EF8063"),
             body=load_fixture("get_lock.online.json"),
         )
 
@@ -318,6 +376,7 @@ class TestApiAsync(aiounittest.AsyncTestCase):
             ACCESS_TOKEN, "A6697750D607098BAE8D6BAA11EF8063"
         )
 
+        assert lock.doorbell is False
         self.assertEqual("A6697750D607098BAE8D6BAA11EF8063", lock.device_id)
         self.assertEqual("Front Door Lock", lock.device_name)
         self.assertEqual("000000000000", lock.house_id)
@@ -343,10 +402,28 @@ class TestApiAsync(aiounittest.AsyncTestCase):
             dateutil.parser.parse("2017-12-10T04:48:30.272Z"), lock.door_state_datetime
         )
 
+    @aioresponses()
+    async def test_async_get_lock_with_doorbell(self, mock):
+        mock.get(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="A6697750D607098BAE8D6BAA11EF8063"),
+            body=load_fixture("lock_with_doorbell.online.json"),
+        )
+
+        api = ApiAsync(ClientSession())
+        lock = await api.async_get_lock_detail(
+            ACCESS_TOKEN, "A6697750D607098BAE8D6BAA11EF8063"
+        )
+
+        assert lock.doorbell is True
+
     @aioresponses()
     async def test_async_get_v2_lock_detail_bridge_online(self, mock):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="snip"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="snip"),
             body=load_fixture("get_lock_v2.online.json"),
         )
 
@@ -404,7 +481,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_lock_detail_bridge_offline(self, mock):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="ABC"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="ABC"),
             body=load_fixture("get_lock.offline.json"),
         )
 
@@ -431,7 +510,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_lock_detail_doorsense_init_state(self, mock):
         mock.get(
-            API_GET_LOCK_URL.format(lock_id="A6697750D607098BAE8D6BAA11EF8063"),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_URL)
+            .format(lock_id="A6697750D607098BAE8D6BAA11EF8063"),
             body=load_fixture("get_lock.doorsense_init.json"),
         )
 
@@ -484,7 +565,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_status_with_locked_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"status": "kAugLockState_Locked"}',
         )
 
@@ -497,7 +580,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_and_door_status_with_locked_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"status": "kAugLockState_Locked"'
             ',"doorState": "kAugLockDoorState_Closed"}',
         )
@@ -514,7 +599,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_status_with_unlocked_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"status": "kAugLockState_Unlocked"}',
         )
 
@@ -527,7 +614,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_status_with_unknown_status_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"status": "not_advertising"}',
         )
 
@@ -540,7 +629,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_door_status_with_closed_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"doorState": "kAugLockDoorState_Closed"}',
         )
 
@@ -553,7 +644,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_door_status_with_open_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"doorState": "kAugLockDoorState_Open"}',
         )
 
@@ -566,7 +659,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_and_door_status_with_open_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"status": "kAugLockState_Unlocked"'
             ',"doorState": "kAugLockDoorState_Open"}',
         )
@@ -583,7 +678,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_lock_door_status_with_unknown_response(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_LOCK_STATUS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_LOCK_STATUS_URL)
+            .format(lock_id=lock_id),
             body='{"doorState": "not_advertising"}',
         )
 
@@ -595,7 +692,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_lock_from_fixture(self, mock):
         lock_id = 1234
-        mock.put(API_LOCK_URL.format(lock_id=lock_id), body=load_fixture("lock.json"))
+        mock.put(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_LOCK_URL)
+            .format(lock_id=lock_id),
+            body=load_fixture("lock.json"),
+        )
 
         api = ApiAsync(ClientSession())
         status = await api.async_lock(ACCESS_TOKEN, lock_id)
@@ -606,7 +708,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_unlock_from_fixture(self, mock):
         lock_id = 1234
         mock.put(
-            API_UNLOCK_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_UNLOCK_URL)
+            .format(lock_id=lock_id),
             body=load_fixture("unlock.json"),
         )
 
@@ -618,7 +722,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_lock_return_activities_from_fixture(self, mock):
         lock_id = 1234
-        mock.put(API_LOCK_URL.format(lock_id=lock_id), body=load_fixture("lock.json"))
+        mock.put(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_LOCK_URL)
+            .format(lock_id=lock_id),
+            body=load_fixture("lock.json"),
+        )
 
         api = ApiAsync(ClientSession())
         activities = await api.async_lock_return_activities(ACCESS_TOKEN, lock_id)
@@ -646,7 +755,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_unlock_return_activities_from_fixture(self, mock):
         lock_id = 1234
         mock.put(
-            API_UNLOCK_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_UNLOCK_URL)
+            .format(lock_id=lock_id),
             body=load_fixture("unlock.json"),
         )
 
@@ -678,7 +789,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     ):
         lock_id = 1234
         mock.put(
-            API_LOCK_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_LOCK_URL)
+            .format(lock_id=lock_id),
             body=load_fixture("lock_without_doorstate.json"),
         )
 
@@ -704,7 +817,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     ):
         lock_id = 1234
         mock.put(
-            API_UNLOCK_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_UNLOCK_URL)
+            .format(lock_id=lock_id),
             body=load_fixture("unlock_without_doorstate.json"),
         )
 
@@ -728,7 +843,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_lock(self, mock):
         lock_id = 1234
         mock.put(
-            API_LOCK_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_LOCK_URL)
+            .format(lock_id=lock_id),
             body='{"status":"locked",'
             '"dateTime":"2017-12-10T07:43:39.056Z",'
             '"isLockStatusChanged":false,'
@@ -744,7 +861,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_lock_async_old_bridge(self, mock):
         lock_id = 1234
         mock.put(
-            API_LOCK_ASYNC_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_LOCK_ASYNC_URL)
+            .format(lock_id=lock_id),
         )
 
         api = ApiAsync(ClientSession())
@@ -753,7 +872,8 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_lock_async_new_bridge(self, mock):
         lock_id = 1234
-        mock.put(f"{API_LOCK_ASYNC_URL}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
+        base_url = ApiCommon(DEFAULT_BRAND).get_brand_url(API_LOCK_ASYNC_URL)
+        mock.put(f"{base_url}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
 
         api = ApiAsync(ClientSession())
         await api.async_lock_async(ACCESS_TOKEN, lock_id)
@@ -761,7 +881,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_unlock(self, mock):
         lock_id = 1234
-        mock.put(API_UNLOCK_URL.format(lock_id=lock_id), body='{"status": "unlocked"}')
+        mock.put(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_UNLOCK_URL)
+            .format(lock_id=lock_id),
+            body='{"status": "unlocked"}',
+        )
 
         api = ApiAsync(ClientSession())
         status = await api.async_unlock(ACCESS_TOKEN, lock_id)
@@ -771,7 +896,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_unlock_async_old_bridge(self, mock):
         lock_id = 1234
-        mock.put(API_UNLOCK_ASYNC_URL.format(lock_id=lock_id))
+
+        mock.put(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_UNLOCK_ASYNC_URL)
+            .format(lock_id=lock_id)
+        )
 
         api = ApiAsync(ClientSession())
         await api.async_unlock_async(ACCESS_TOKEN, lock_id, hyper_bridge=False)
@@ -779,7 +909,8 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_unlock_async_new_bridge(self, mock):
         lock_id = 1234
-        mock.put(f"{API_UNLOCK_ASYNC_URL}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
+        base_url = ApiCommon(DEFAULT_BRAND).get_brand_url(API_UNLOCK_ASYNC_URL)
+        mock.put(f"{base_url}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
 
         api = ApiAsync(ClientSession())
         await api.async_unlock_async(ACCESS_TOKEN, lock_id, hyper_bridge=True)
@@ -787,7 +918,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_status_async_old_bridge(self, mock):
         lock_id = 1234
-        mock.put(API_STATUS_ASYNC_URL.format(lock_id=lock_id))
+
+        mock.put(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_STATUS_ASYNC_URL)
+            .format(lock_id=lock_id)
+        )
 
         api = ApiAsync(ClientSession())
         await api.async_status_async(ACCESS_TOKEN, lock_id, hyper_bridge=False)
@@ -795,7 +931,8 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_status_async_new_bridge(self, mock):
         lock_id = 1234
-        mock.put(f"{API_STATUS_ASYNC_URL}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
+        base_url = ApiCommon(DEFAULT_BRAND).get_brand_url(API_STATUS_ASYNC_URL)
+        mock.put(f"{base_url}{HYPER_BRIDGE_PARAM}".format(lock_id=lock_id))
 
         api = ApiAsync(ClientSession())
         await api.async_status_async(ACCESS_TOKEN, lock_id)
@@ -804,7 +941,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     async def test_async_get_pins(self, mock):
         lock_id = 1234
         mock.get(
-            API_GET_PINS_URL.format(lock_id=lock_id),
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_PINS_URL)
+            .format(lock_id=lock_id),
             body=load_fixture("get_pins.json"),
         )
 
@@ -834,8 +973,12 @@ class TestApiAsync(aiounittest.AsyncTestCase):
     @aioresponses()
     async def test_async_get_house_activities(self, mock):
         house_id = 1234
+
         mock.get(
-            API_GET_HOUSE_ACTIVITIES_URL.format(house_id=house_id) + "?limit=8",
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_HOUSE_ACTIVITIES_URL)
+            .format(house_id=house_id)
+            + "?limit=8",
             body=load_fixture("get_house_activities.json"),
         )
 
@@ -855,10 +998,30 @@ class TestApiAsync(aiounittest.AsyncTestCase):
         self.assertIsInstance(activities[8], yalexs.activity.LockOperationActivity)
         self.assertIsInstance(activities[9], yalexs.activity.LockOperationActivity)
 
+    @aioresponses()
+    async def test_async_get_retry_raises_our_exception_class(self, mock):
+        house_id = 1234
+
+        mock.get(
+            ApiCommon(DEFAULT_BRAND)
+            .get_brand_url(API_GET_HOUSE_ACTIVITIES_URL)
+            .format(house_id=house_id)
+            + "?limit=8",
+            exception=ClientOSError("any"),
+        )
+
+        api = ApiAsync(ClientSession())
+        with patch.object(api_async, "API_EXCEPTION_RETRY_TIME", 0), pytest.raises(
+            AugustApiAIOHTTPError
+        ):
+            await api.async_get_house_activities(ACCESS_TOKEN, house_id)
+
     @aioresponses()
     async def test_async_refresh_access_token(self, mock):
         mock.get(
-            API_GET_HOUSES_URL, body="{}", headers={"x-august-access-token": "xyz"}
+            ApiCommon(DEFAULT_BRAND).get_brand_url(API_GET_HOUSES_URL),
+            body="{}",
+            headers={"x-august-access-token": "xyz"},
         )
 
         api = ApiAsync(ClientSession())
@@ -874,7 +1037,10 @@ class TestApiAsync(aiounittest.AsyncTestCase):
             return CallbackResult(status=200, body="{}")
 
         mock.post(
-            API_VALIDATE_VERIFICATION_CODE_URLS["email"], callback=response_callback
+            ApiCommon(DEFAULT_BRAND).get_brand_url(
+                API_VALIDATE_VERIFICATION_CODE_URLS["email"]
+            ),
+            callback=response_callback,
         )
 
         api = ApiAsync(ClientSession())
@@ -908,9 +1074,9 @@ class TestApiAsync(aiounittest.AsyncTestCase):
 
         ERROR_MAP = {
             560: "The operation failed with error code 560: 560.",
-            422: "The operation failed because the bridge (connect) is offline.",
-            423: "The operation failed because the bridge (connect) is in use.",
-            408: "The operation timed out because the bridge (connect) failed to respond.",
+            422: "The operation failed because the bridge (connect) is offline: 422",
+            423: "The operation failed because the bridge (connect) is in use: 423",
+            408: "The operation timed out because the bridge (connect) failed to respond: 408",
         }
 
         for status_code in ERROR_MAP:
@@ -934,7 +1100,10 @@ class TestApiAsync(aiounittest.AsyncTestCase):
 
     @aioresponses()
     async def test_async_get_usern(self, mock):
-        mock.get(API_GET_USER_URL, body='{"UserID": "abc"}')
+        mock.get(
+            ApiCommon(DEFAULT_BRAND).get_brand_url(API_GET_USER_URL),
+            body='{"UserID": "abc"}',
+        )
 
         api = ApiAsync(ClientSession())
         user_details = await api.async_get_user("token")
