@@ -1,46 +1,56 @@
-import datetime
+from __future__ import annotations
 
-import dateutil.parser
+import datetime
+from typing import Any
+
+from aiohttp import ClientSession
 import requests
 
-from yalexs.device import Device, DeviceDetail
+from .backports.functools import cached_property
+from .device import Device, DeviceDetail
+from .time import parse_datetime
 
 DOORBELL_STATUS_KEY = "status"
 
 
 class Doorbell(Device):
-    def __init__(self, device_id, data):
+    def __init__(self, device_id: str, data: dict[str, Any]) -> None:
         super().__init__(device_id, data["name"], data["HouseID"])
         self._serial_number = data["serialNumber"]
         self._status = data["status"]
         recent_image = data.get("recentImage", {})
         self._image_url = recent_image.get("secure_url", None)
         self._has_subscription = data.get("dvrSubscriptionSetupDone", False)
+        self._content_token = data.get("contentToken", "")
 
-    @property
+    @cached_property
     def serial_number(self):
         return self._serial_number
 
-    @property
+    @cached_property
     def status(self):
         return self._status
 
-    @property
+    @cached_property
     def is_standby(self):
         return self.status == "standby"
 
-    @property
+    @cached_property
     def is_online(self):
         return self.status == "doorbell_call_status_online"
 
-    @property
+    @cached_property
     def image_url(self):
         return self._image_url
 
-    @property
+    @cached_property
     def has_subscription(self):
         return self._has_subscription
 
+    @cached_property
+    def content_token(self):
+        return self._content_token
+
     def __repr__(self):
         return "Doorbell(id={}, name={}, house_id={})".format(
             self.device_id, self.device_name, self.house_id
@@ -65,14 +75,13 @@ class DoorbellDetail(DeviceDetail):
         self._has_subscription = data.get("dvrSubscriptionSetupDone", False)
         self._image_created_at_datetime = None
         self._model = None
+        self._content_token = data.get("contentToken", "")
 
         if "type" in data:
             self._model = data["type"]
 
         if "created_at" in recent_image:
-            self._image_created_at_datetime = dateutil.parser.parse(
-                recent_image["created_at"]
-            )
+            self._image_created_at_datetime = parse_datetime(recent_image["created_at"])
 
         self._battery_level = None
         if "telemetry" in data:
@@ -92,19 +101,19 @@ class DoorbellDetail(DeviceDetail):
                 else:
                     self._battery_level = 25
 
-    @property
+    @cached_property
     def status(self):
         return self._status
 
-    @property
+    @cached_property
     def model(self):
         return self._model
 
-    @property
+    @cached_property
     def is_online(self):
         return self.status == "doorbell_call_status_online"
 
-    @property
+    @cached_property
     def is_standby(self):
         return self.status == "standby"
 
@@ -128,20 +137,29 @@ class DoorbellDetail(DeviceDetail):
         """Update the doorbell image url (usually form the activity log)."""
         self._image_url = var
 
-    @property
+    @cached_property
     def battery_level(self):
         """Return an approximation of the battery percentage."""
         return self._battery_level
 
-    @property
+    @cached_property
     def has_subscription(self):
         return self._has_subscription
 
-    async def async_get_doorbell_image(self, aiohttp_session, timeout=10):
+    async def async_get_doorbell_image(
+        self, aiohttp_session: ClientSession, timeout=10
+    ) -> bytes:
         response = await aiohttp_session.request(
-            "get", self._image_url, timeout=timeout
+            "get",
+            self._image_url,
+            timeout=timeout,
+            headers={"Authorization": self._content_token},
         )
         return await response.read()
 
-    def get_doorbell_image(self, timeout=10):
-        return requests.get(self._image_url, timeout=timeout).content
+    def get_doorbell_image(self, timeout=10) -> bytes:
+        return requests.get(
+            self._image_url,
+            timeout=timeout,
+            headers={"Authorization": self._content_token},
+        ).content
